# coding: utf-8

# flake8: noqa
"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from pygreenfield.models.add_customer_email_request import AddCustomerEmailRequest
from pygreenfield.models.all_of_application_user_data_created import AllOfApplicationUserDataCreated
from pygreenfield.models.all_of_checkout_options_expiration_minutes import AllOfCheckoutOptionsExpirationMinutes
from pygreenfield.models.all_of_checkout_options_monitoring_minutes import AllOfCheckoutOptionsMonitoringMinutes
from pygreenfield.models.all_of_create_lightning_invoice_request_expiry import AllOfCreateLightningInvoiceRequestExpiry
from pygreenfield.models.all_of_lightning_automated_transfer_settings_interval_seconds import AllOfLightningAutomatedTransferSettingsIntervalSeconds
from pygreenfield.models.all_of_lightning_invoice_data_expires_at import AllOfLightningInvoiceDataExpiresAt
from pygreenfield.models.all_of_lightning_invoice_data_paid_at import AllOfLightningInvoiceDataPaidAt
from pygreenfield.models.all_of_lightning_payment_data_created_at import AllOfLightningPaymentDataCreatedAt
from pygreenfield.models.all_of_notification_data_created_time import AllOfNotificationDataCreatedTime
from pygreenfield.models.all_of_on_chain_automated_transfer_settings_interval_seconds import AllOfOnChainAutomatedTransferSettingsIntervalSeconds
from pygreenfield.models.all_of_on_chain_wallet_transaction_data_timestamp import AllOfOnChainWalletTransactionDataTimestamp
from pygreenfield.models.all_of_on_chain_wallet_utxo_data_timestamp import AllOfOnChainWalletUTXODataTimestamp
from pygreenfield.models.all_of_payment_received_date import AllOfPaymentReceivedDate
from pygreenfield.models.all_of_payment_request_base_data_expiry_date import AllOfPaymentRequestBaseDataExpiryDate
from pygreenfield.models.all_of_store_base_data_invoice_expiration import AllOfStoreBaseDataInvoiceExpiration
from pygreenfield.models.all_of_store_base_data_monitoring_expiration import AllOfStoreBaseDataMonitoringExpiration
from pygreenfield.models.all_of_update_lightning_automated_transfer_settings_interval_seconds import AllOfUpdateLightningAutomatedTransferSettingsIntervalSeconds
from pygreenfield.models.all_of_update_on_chain_automated_transfer_settings_interval_seconds import AllOfUpdateOnChainAutomatedTransferSettingsIntervalSeconds
from pygreenfield.models.all_of_webhook_delivery_data_timestamp import AllOfWebhookDeliveryDataTimestamp
from pygreenfield.models.all_of_webhook_event_timestamp import AllOfWebhookEventTimestamp
from pygreenfield.models.any_of_invoice_metadata import AnyOfInvoiceMetadata
from pygreenfield.models.any_of_invoice_payment_method_data_model_additional_data import AnyOfInvoicePaymentMethodDataModelAdditionalData
from pygreenfield.models.api_key_data import ApiKeyData
from pygreenfield.models.application_health_data import ApplicationHealthData
from pygreenfield.models.application_server_info_data import ApplicationServerInfoData
from pygreenfield.models.application_server_info_node_status_data import ApplicationServerInfoNodeStatusData
from pygreenfield.models.application_server_info_sync_status_data import ApplicationServerInfoSyncStatusData
from pygreenfield.models.application_user_data import ApplicationUserData
from pygreenfield.models.apps_pos_body import AppsPosBody
from pygreenfield.models.asset_balance_data import AssetBalanceData
from pygreenfield.models.basic_app_data import BasicAppData
from pygreenfield.models.checkout_options import CheckoutOptions
from pygreenfield.models.connect_to_node_request import ConnectToNodeRequest
from pygreenfield.models.create_custodian_account_request import CreateCustodianAccountRequest
from pygreenfield.models.create_invoice_request import CreateInvoiceRequest
from pygreenfield.models.create_lightning_invoice_request import CreateLightningInvoiceRequest
from pygreenfield.models.create_on_chain_transaction_request import CreateOnChainTransactionRequest
from pygreenfield.models.create_on_chain_transaction_request_destination import CreateOnChainTransactionRequestDestination
from pygreenfield.models.create_payout_request import CreatePayoutRequest
from pygreenfield.models.create_payout_through_store_request import CreatePayoutThroughStoreRequest
from pygreenfield.models.crypto_code_preview_body import CryptoCodePreviewBody
from pygreenfield.models.custodian_account_data import CustodianAccountData
from pygreenfield.models.custodian_data import CustodianData
from pygreenfield.models.email_data import EmailData
from pygreenfield.models.email_settings_data import EmailSettingsData
from pygreenfield.models.generate_on_chain_wallet_request import GenerateOnChainWalletRequest
from pygreenfield.models.generic_payment_method_data import GenericPaymentMethodData
from pygreenfield.models.inline_response200 import InlineResponse200
from pygreenfield.models.inline_response2001 import InlineResponse2001
from pygreenfield.models.inline_response2002 import InlineResponse2002
from pygreenfield.models.inline_response2003 import InlineResponse2003
from pygreenfield.models.inline_response403 import InlineResponse403
from pygreenfield.models.invoice_additional_status import InvoiceAdditionalStatus
from pygreenfield.models.invoice_data import InvoiceData
from pygreenfield.models.invoice_data_base import InvoiceDataBase
from pygreenfield.models.invoice_data_list import InvoiceDataList
from pygreenfield.models.invoice_metadata import InvoiceMetadata
from pygreenfield.models.invoice_metadata_pos_object import InvoiceMetadataPosObject
from pygreenfield.models.invoice_metadata_pos_string import InvoiceMetadataPosString
from pygreenfield.models.invoice_payment_method_data_model import InvoicePaymentMethodDataModel
from pygreenfield.models.invoice_status import InvoiceStatus
from pygreenfield.models.invoice_status_mark import InvoiceStatusMark
from pygreenfield.models.invoice_type import InvoiceType
from pygreenfield.models.lnurl_pay_payment_method_base_data import LNURLPayPaymentMethodBaseData
from pygreenfield.models.lnurl_pay_payment_method_data import LNURLPayPaymentMethodData
from pygreenfield.models.lnurl_pay_payment_method_data_list import LNURLPayPaymentMethodDataList
from pygreenfield.models.label_data import LabelData
from pygreenfield.models.ledger_entry_data import LedgerEntryData
from pygreenfield.models.ledger_entry_type import LedgerEntryType
from pygreenfield.models.lightning_automated_transfer_settings import LightningAutomatedTransferSettings
from pygreenfield.models.lightning_channel_data import LightningChannelData
from pygreenfield.models.lightning_invoice_data import LightningInvoiceData
from pygreenfield.models.lightning_invoice_status import LightningInvoiceStatus
from pygreenfield.models.lightning_network_payment_method_base_data import LightningNetworkPaymentMethodBaseData
from pygreenfield.models.lightning_network_payment_method_data import LightningNetworkPaymentMethodData
from pygreenfield.models.lightning_network_payment_method_data_list import LightningNetworkPaymentMethodDataList
from pygreenfield.models.lightning_node_balance_data import LightningNodeBalanceData
from pygreenfield.models.lightning_node_information_data import LightningNodeInformationData
from pygreenfield.models.lightning_payment_data import LightningPaymentData
from pygreenfield.models.lightning_payment_status import LightningPaymentStatus
from pygreenfield.models.lock_user_request import LockUserRequest
from pygreenfield.models.mark_invoice_status_request import MarkInvoiceStatusRequest
from pygreenfield.models.network_fee_mode import NetworkFeeMode
from pygreenfield.models.notification_data import NotificationData
from pygreenfield.models.offchain_balance_data import OffchainBalanceData
from pygreenfield.models.on_chain_automated_transfer_settings import OnChainAutomatedTransferSettings
from pygreenfield.models.on_chain_payment_method_base_data import OnChainPaymentMethodBaseData
from pygreenfield.models.on_chain_payment_method_data import OnChainPaymentMethodData
from pygreenfield.models.on_chain_payment_method_data_list import OnChainPaymentMethodDataList
from pygreenfield.models.on_chain_payment_method_data_preview import OnChainPaymentMethodDataPreview
from pygreenfield.models.on_chain_payment_method_data_with_sensitive_data import OnChainPaymentMethodDataWithSensitiveData
from pygreenfield.models.on_chain_payment_method_preview_result_address_item import OnChainPaymentMethodPreviewResultAddressItem
from pygreenfield.models.on_chain_payment_method_preview_result_data import OnChainPaymentMethodPreviewResultData
from pygreenfield.models.on_chain_wallet_address_data import OnChainWalletAddressData
from pygreenfield.models.on_chain_wallet_fee_rate_data import OnChainWalletFeeRateData
from pygreenfield.models.on_chain_wallet_overview_data import OnChainWalletOverviewData
from pygreenfield.models.on_chain_wallet_transaction_data import OnChainWalletTransactionData
from pygreenfield.models.on_chain_wallet_utxo_data import OnChainWalletUTXOData
from pygreenfield.models.onchain_balance_data import OnchainBalanceData
from pygreenfield.models.one_of_generic_payment_method_data_data import OneOfGenericPaymentMethodDataData
from pygreenfield.models.one_of_trade_request_data_qty import OneOfTradeRequestDataQty
from pygreenfield.models.one_ofinline_response2003 import OneOfinlineResponse2003
from pygreenfield.models.one_ofinline_response403 import OneOfinlineResponse403
from pygreenfield.models.open_lightning_channel_request import OpenLightningChannelRequest
from pygreenfield.models.patch_on_chain_transaction_request import PatchOnChainTransactionRequest
from pygreenfield.models.pay_lightning_invoice_request import PayLightningInvoiceRequest
from pygreenfield.models.payment import Payment
from pygreenfield.models.payment_request_base_data import PaymentRequestBaseData
from pygreenfield.models.payment_request_data import PaymentRequestData
from pygreenfield.models.payment_request_data_list import PaymentRequestDataList
from pygreenfield.models.payment_status import PaymentStatus
from pygreenfield.models.payout_data import PayoutData
from pygreenfield.models.payout_data_list import PayoutDataList
from pygreenfield.models.payout_processor_data import PayoutProcessorData
from pygreenfield.models.payouts_payout_id_body import PayoutsPayoutIdBody
from pygreenfield.models.point_of_sale_app_data import PointOfSaleAppData
from pygreenfield.models.problem_details import ProblemDetails
from pygreenfield.models.pull_payment_data import PullPaymentData
from pygreenfield.models.pull_payment_data_list import PullPaymentDataList
from pygreenfield.models.quote_result_data import QuoteResultData
from pygreenfield.models.receipt_options import ReceiptOptions
from pygreenfield.models.speed_policy import SpeedPolicy
from pygreenfield.models.store_base_data import StoreBaseData
from pygreenfield.models.store_data import StoreData
from pygreenfield.models.store_data_list import StoreDataList
from pygreenfield.models.store_id_pullpayments_body import StoreIdPullpaymentsBody
from pygreenfield.models.store_user_data import StoreUserData
from pygreenfield.models.store_user_data_list import StoreUserDataList
from pygreenfield.models.time_span import TimeSpan
from pygreenfield.models.time_span_minutes import TimeSpanMinutes
from pygreenfield.models.time_span_seconds import TimeSpanSeconds
from pygreenfield.models.trade_request_data import TradeRequestData
from pygreenfield.models.trade_result_data import TradeResultData
from pygreenfield.models.transaction_status import TransactionStatus
from pygreenfield.models.unix_timestamp import UnixTimestamp
from pygreenfield.models.update_invoice_request import UpdateInvoiceRequest
from pygreenfield.models.update_lightning_automated_transfer_settings import UpdateLightningAutomatedTransferSettings
from pygreenfield.models.update_lightning_network_payment_method_request import UpdateLightningNetworkPaymentMethodRequest
from pygreenfield.models.update_notification import UpdateNotification
from pygreenfield.models.update_on_chain_automated_transfer_settings import UpdateOnChainAutomatedTransferSettings
from pygreenfield.models.update_on_chain_payment_method_request import UpdateOnChainPaymentMethodRequest
from pygreenfield.models.v1_apikeys_body import V1ApikeysBody
from pygreenfield.models.v1_users_body import V1UsersBody
from pygreenfield.models.validation_problem_details import ValidationProblemDetails
from pygreenfield.models.validation_problem_details_inner import ValidationProblemDetailsInner
from pygreenfield.models.webhook_data import WebhookData
from pygreenfield.models.webhook_data_base import WebhookDataBase
from pygreenfield.models.webhook_data_base_authorized_events import WebhookDataBaseAuthorizedEvents
from pygreenfield.models.webhook_data_create import WebhookDataCreate
from pygreenfield.models.webhook_data_list import WebhookDataList
from pygreenfield.models.webhook_delivery_data import WebhookDeliveryData
from pygreenfield.models.webhook_delivery_list import WebhookDeliveryList
from pygreenfield.models.webhook_event import WebhookEvent
from pygreenfield.models.webhook_invoice_event import WebhookInvoiceEvent
from pygreenfield.models.webhook_invoice_expired_event import WebhookInvoiceExpiredEvent
from pygreenfield.models.webhook_invoice_invalid_event import WebhookInvoiceInvalidEvent
from pygreenfield.models.webhook_invoice_payment_settled_event import WebhookInvoicePaymentSettledEvent
from pygreenfield.models.webhook_invoice_processing_event import WebhookInvoiceProcessingEvent
from pygreenfield.models.webhook_invoice_received_payment_event import WebhookInvoiceReceivedPaymentEvent
from pygreenfield.models.webhook_invoice_settled_event import WebhookInvoiceSettledEvent
from pygreenfield.models.withdrawal_request_data import WithdrawalRequestData
from pygreenfield.models.withdrawal_result_data import WithdrawalResultData



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateOnChainPaymentMethodRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'derivation_scheme': 'str',
        'label': 'str',
        'account_key_path': 'str'
    }

    attribute_map = {
        'derivation_scheme': 'derivationScheme',
        'label': 'label',
        'account_key_path': 'accountKeyPath'
    }

    def __init__(self, derivation_scheme=None, label=None, account_key_path=None):  # noqa: E501
        """UpdateOnChainPaymentMethodRequest - a model defined in Swagger"""  # noqa: E501
        self._derivation_scheme = None
        self._label = None
        self._account_key_path = None
        self.discriminator = None
        if derivation_scheme is not None:
            self.derivation_scheme = derivation_scheme
        if label is not None:
            self.label = label
        if account_key_path is not None:
            self.account_key_path = account_key_path

    @property
    def derivation_scheme(self):
        """Gets the derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        The derivation scheme  # noqa: E501

        :return: The derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._derivation_scheme

    @derivation_scheme.setter
    def derivation_scheme(self, derivation_scheme):
        """Sets the derivation_scheme of this UpdateOnChainPaymentMethodRequest.

        The derivation scheme  # noqa: E501

        :param derivation_scheme: The derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._derivation_scheme = derivation_scheme

    @property
    def label(self):
        """Gets the label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        A label that will be shown in the UI  # noqa: E501

        :return: The label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this UpdateOnChainPaymentMethodRequest.

        A label that will be shown in the UI  # noqa: E501

        :param label: The label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def account_key_path(self):
        """Gets the account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs  # noqa: E501

        :return: The account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_key_path

    @account_key_path.setter
    def account_key_path(self, account_key_path):
        """Sets the account_key_path of this UpdateOnChainPaymentMethodRequest.

        The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs  # noqa: E501

        :param account_key_path: The account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._account_key_path = account_key_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateOnChainPaymentMethodRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateOnChainPaymentMethodRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookDeliveryData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'timestamp': 'AllOfWebhookDeliveryDataTimestamp',
        'http_code': 'float',
        'error_message': 'str',
        'status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'timestamp': 'timestamp',
        'http_code': 'httpCode',
        'error_message': 'errorMessage',
        'status': 'status'
    }

    def __init__(self, id=None, timestamp=None, http_code=None, error_message=None, status=None):  # noqa: E501
        """WebhookDeliveryData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._timestamp = None
        self._http_code = None
        self._error_message = None
        self._status = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if timestamp is not None:
            self.timestamp = timestamp
        if http_code is not None:
            self.http_code = http_code
        if error_message is not None:
            self.error_message = error_message
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this WebhookDeliveryData.  # noqa: E501

        The id of the delivery  # noqa: E501

        :return: The id of this WebhookDeliveryData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDeliveryData.

        The id of the delivery  # noqa: E501

        :param id: The id of this WebhookDeliveryData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def timestamp(self):
        """Gets the timestamp of this WebhookDeliveryData.  # noqa: E501

        Timestamp of when the delivery got broadcasted  # noqa: E501

        :return: The timestamp of this WebhookDeliveryData.  # noqa: E501
        :rtype: AllOfWebhookDeliveryDataTimestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this WebhookDeliveryData.

        Timestamp of when the delivery got broadcasted  # noqa: E501

        :param timestamp: The timestamp of this WebhookDeliveryData.  # noqa: E501
        :type: AllOfWebhookDeliveryDataTimestamp
        """

        self._timestamp = timestamp

    @property
    def http_code(self):
        """Gets the http_code of this WebhookDeliveryData.  # noqa: E501

        HTTP code received by the remote service, if any.  # noqa: E501

        :return: The http_code of this WebhookDeliveryData.  # noqa: E501
        :rtype: float
        """
        return self._http_code

    @http_code.setter
    def http_code(self, http_code):
        """Sets the http_code of this WebhookDeliveryData.

        HTTP code received by the remote service, if any.  # noqa: E501

        :param http_code: The http_code of this WebhookDeliveryData.  # noqa: E501
        :type: float
        """

        self._http_code = http_code

    @property
    def error_message(self):
        """Gets the error_message of this WebhookDeliveryData.  # noqa: E501

        User friendly error message, if any.  # noqa: E501

        :return: The error_message of this WebhookDeliveryData.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this WebhookDeliveryData.

        User friendly error message, if any.  # noqa: E501

        :param error_message: The error_message of this WebhookDeliveryData.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def status(self):
        """Gets the status of this WebhookDeliveryData.  # noqa: E501

        Whether the delivery failed or not (possible values are: `Failed`, `HttpError`, `HttpSuccess`)  # noqa: E501

        :return: The status of this WebhookDeliveryData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WebhookDeliveryData.

        Whether the delivery failed or not (possible values are: `Failed`, `HttpError`, `HttpSuccess`)  # noqa: E501

        :param status: The status of this WebhookDeliveryData.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookDeliveryData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDeliveryData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CheckoutOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'speed_policy': 'SpeedPolicy',
        'payment_methods': 'list[str]',
        'default_payment_method': 'str',
        'expiration_minutes': 'AllOfCheckoutOptionsExpirationMinutes',
        'monitoring_minutes': 'AllOfCheckoutOptionsMonitoringMinutes',
        'payment_tolerance': 'float',
        'redirect_url': 'str',
        'redirect_automatically': 'bool',
        'requires_refund_email': 'bool',
        'default_language': 'str'
    }

    attribute_map = {
        'speed_policy': 'speedPolicy',
        'payment_methods': 'paymentMethods',
        'default_payment_method': 'defaultPaymentMethod',
        'expiration_minutes': 'expirationMinutes',
        'monitoring_minutes': 'monitoringMinutes',
        'payment_tolerance': 'paymentTolerance',
        'redirect_url': 'redirectURL',
        'redirect_automatically': 'redirectAutomatically',
        'requires_refund_email': 'requiresRefundEmail',
        'default_language': 'defaultLanguage'
    }

    def __init__(self, speed_policy=None, payment_methods=None, default_payment_method=None, expiration_minutes=None, monitoring_minutes=None, payment_tolerance=None, redirect_url=None, redirect_automatically=None, requires_refund_email=None, default_language=None):  # noqa: E501
        """CheckoutOptions - a model defined in Swagger"""  # noqa: E501
        self._speed_policy = None
        self._payment_methods = None
        self._default_payment_method = None
        self._expiration_minutes = None
        self._monitoring_minutes = None
        self._payment_tolerance = None
        self._redirect_url = None
        self._redirect_automatically = None
        self._requires_refund_email = None
        self._default_language = None
        self.discriminator = None
        if speed_policy is not None:
            self.speed_policy = speed_policy
        if payment_methods is not None:
            self.payment_methods = payment_methods
        if default_payment_method is not None:
            self.default_payment_method = default_payment_method
        if expiration_minutes is not None:
            self.expiration_minutes = expiration_minutes
        if monitoring_minutes is not None:
            self.monitoring_minutes = monitoring_minutes
        if payment_tolerance is not None:
            self.payment_tolerance = payment_tolerance
        if redirect_url is not None:
            self.redirect_url = redirect_url
        if redirect_automatically is not None:
            self.redirect_automatically = redirect_automatically
        if requires_refund_email is not None:
            self.requires_refund_email = requires_refund_email
        if default_language is not None:
            self.default_language = default_language

    @property
    def speed_policy(self):
        """Gets the speed_policy of this CheckoutOptions.  # noqa: E501


        :return: The speed_policy of this CheckoutOptions.  # noqa: E501
        :rtype: SpeedPolicy
        """
        return self._speed_policy

    @speed_policy.setter
    def speed_policy(self, speed_policy):
        """Sets the speed_policy of this CheckoutOptions.


        :param speed_policy: The speed_policy of this CheckoutOptions.  # noqa: E501
        :type: SpeedPolicy
        """

        self._speed_policy = speed_policy

    @property
    def payment_methods(self):
        """Gets the payment_methods of this CheckoutOptions.  # noqa: E501

        A specific set of payment methods to use for this invoice (ie. BTC, BTC-LightningNetwork). By default, select all payment methods enabled in the store.  # noqa: E501

        :return: The payment_methods of this CheckoutOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this CheckoutOptions.

        A specific set of payment methods to use for this invoice (ie. BTC, BTC-LightningNetwork). By default, select all payment methods enabled in the store.  # noqa: E501

        :param payment_methods: The payment_methods of this CheckoutOptions.  # noqa: E501
        :type: list[str]
        """

        self._payment_methods = payment_methods

    @property
    def default_payment_method(self):
        """Gets the default_payment_method of this CheckoutOptions.  # noqa: E501

        Default payment type for the invoice (e.g., BTC, BTC-LightningNetwork). Default payment method set for the store is used if this parameter is not specified.  # noqa: E501

        :return: The default_payment_method of this CheckoutOptions.  # noqa: E501
        :rtype: str
        """
        return self._default_payment_method

    @default_payment_method.setter
    def default_payment_method(self, default_payment_method):
        """Sets the default_payment_method of this CheckoutOptions.

        Default payment type for the invoice (e.g., BTC, BTC-LightningNetwork). Default payment method set for the store is used if this parameter is not specified.  # noqa: E501

        :param default_payment_method: The default_payment_method of this CheckoutOptions.  # noqa: E501
        :type: str
        """

        self._default_payment_method = default_payment_method

    @property
    def expiration_minutes(self):
        """Gets the expiration_minutes of this CheckoutOptions.  # noqa: E501

        The number of minutes after which an invoice becomes expired. Defaults to the store's settings. (The default store settings is 15)  # noqa: E501

        :return: The expiration_minutes of this CheckoutOptions.  # noqa: E501
        :rtype: AllOfCheckoutOptionsExpirationMinutes
        """
        return self._expiration_minutes

    @expiration_minutes.setter
    def expiration_minutes(self, expiration_minutes):
        """Sets the expiration_minutes of this CheckoutOptions.

        The number of minutes after which an invoice becomes expired. Defaults to the store's settings. (The default store settings is 15)  # noqa: E501

        :param expiration_minutes: The expiration_minutes of this CheckoutOptions.  # noqa: E501
        :type: AllOfCheckoutOptionsExpirationMinutes
        """

        self._expiration_minutes = expiration_minutes

    @property
    def monitoring_minutes(self):
        """Gets the monitoring_minutes of this CheckoutOptions.  # noqa: E501

        The number of minutes after an invoice expired after which we are still monitoring for incoming payments. Defaults to the store's settings. (The default store settings is 1440, 1 day)  # noqa: E501

        :return: The monitoring_minutes of this CheckoutOptions.  # noqa: E501
        :rtype: AllOfCheckoutOptionsMonitoringMinutes
        """
        return self._monitoring_minutes

    @monitoring_minutes.setter
    def monitoring_minutes(self, monitoring_minutes):
        """Sets the monitoring_minutes of this CheckoutOptions.

        The number of minutes after an invoice expired after which we are still monitoring for incoming payments. Defaults to the store's settings. (The default store settings is 1440, 1 day)  # noqa: E501

        :param monitoring_minutes: The monitoring_minutes of this CheckoutOptions.  # noqa: E501
        :type: AllOfCheckoutOptionsMonitoringMinutes
        """

        self._monitoring_minutes = monitoring_minutes

    @property
    def payment_tolerance(self):
        """Gets the payment_tolerance of this CheckoutOptions.  # noqa: E501

        A percentage determining whether to count the invoice as paid when the invoice is paid within the specified margin of error. Defaults to the store's settings. (The default store settings is 100)  # noqa: E501

        :return: The payment_tolerance of this CheckoutOptions.  # noqa: E501
        :rtype: float
        """
        return self._payment_tolerance

    @payment_tolerance.setter
    def payment_tolerance(self, payment_tolerance):
        """Sets the payment_tolerance of this CheckoutOptions.

        A percentage determining whether to count the invoice as paid when the invoice is paid within the specified margin of error. Defaults to the store's settings. (The default store settings is 100)  # noqa: E501

        :param payment_tolerance: The payment_tolerance of this CheckoutOptions.  # noqa: E501
        :type: float
        """

        self._payment_tolerance = payment_tolerance

    @property
    def redirect_url(self):
        """Gets the redirect_url of this CheckoutOptions.  # noqa: E501

        When the customer has paid the invoice, the URL where the customer will be redirected when clicking on the `return to store` button. You can use placeholders `{InvoiceId}` or `{OrderId}` in the URL, BTCPay Server will replace those with this invoice `id` or `metadata.orderId` respectively.  # noqa: E501

        :return: The redirect_url of this CheckoutOptions.  # noqa: E501
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """Sets the redirect_url of this CheckoutOptions.

        When the customer has paid the invoice, the URL where the customer will be redirected when clicking on the `return to store` button. You can use placeholders `{InvoiceId}` or `{OrderId}` in the URL, BTCPay Server will replace those with this invoice `id` or `metadata.orderId` respectively.  # noqa: E501

        :param redirect_url: The redirect_url of this CheckoutOptions.  # noqa: E501
        :type: str
        """

        self._redirect_url = redirect_url

    @property
    def redirect_automatically(self):
        """Gets the redirect_automatically of this CheckoutOptions.  # noqa: E501

        When the customer has paid the invoice, and a `redirectURL` is set, the checkout is redirected to `redirectURL` automatically if `redirectAutomatically` is true. Defaults to the store's settings. (The default store settings is false)  # noqa: E501

        :return: The redirect_automatically of this CheckoutOptions.  # noqa: E501
        :rtype: bool
        """
        return self._redirect_automatically

    @redirect_automatically.setter
    def redirect_automatically(self, redirect_automatically):
        """Sets the redirect_automatically of this CheckoutOptions.

        When the customer has paid the invoice, and a `redirectURL` is set, the checkout is redirected to `redirectURL` automatically if `redirectAutomatically` is true. Defaults to the store's settings. (The default store settings is false)  # noqa: E501

        :param redirect_automatically: The redirect_automatically of this CheckoutOptions.  # noqa: E501
        :type: bool
        """

        self._redirect_automatically = redirect_automatically

    @property
    def requires_refund_email(self):
        """Gets the requires_refund_email of this CheckoutOptions.  # noqa: E501

        Invoice will require user to provide a refund email if this option is set to `true`. Has no effect if `buyerEmail` metadata is set as there is no email to collect in this case.  # noqa: E501

        :return: The requires_refund_email of this CheckoutOptions.  # noqa: E501
        :rtype: bool
        """
        return self._requires_refund_email

    @requires_refund_email.setter
    def requires_refund_email(self, requires_refund_email):
        """Sets the requires_refund_email of this CheckoutOptions.

        Invoice will require user to provide a refund email if this option is set to `true`. Has no effect if `buyerEmail` metadata is set as there is no email to collect in this case.  # noqa: E501

        :param requires_refund_email: The requires_refund_email of this CheckoutOptions.  # noqa: E501
        :type: bool
        """

        self._requires_refund_email = requires_refund_email

    @property
    def default_language(self):
        """Gets the default_language of this CheckoutOptions.  # noqa: E501

        The language code (eg. en-US, en, fr-FR...) of the language presented to your customer in the checkout page. BTCPay Server tries to match the best language available. If null or not set, will fallback on the store's default language. You can see the list of language codes with [this operation](#operation/langCodes).  # noqa: E501

        :return: The default_language of this CheckoutOptions.  # noqa: E501
        :rtype: str
        """
        return self._default_language

    @default_language.setter
    def default_language(self, default_language):
        """Sets the default_language of this CheckoutOptions.

        The language code (eg. en-US, en, fr-FR...) of the language presented to your customer in the checkout page. BTCPay Server tries to match the best language available. If null or not set, will fallback on the store's default language. You can see the list of language codes with [this operation](#operation/langCodes).  # noqa: E501

        :param default_language: The default_language of this CheckoutOptions.  # noqa: E501
        :type: str
        """

        self._default_language = default_language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CheckoutOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckoutOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreatePayoutRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination': 'str',
        'amount': 'str',
        'payment_method': 'str'
    }

    attribute_map = {
        'destination': 'destination',
        'amount': 'amount',
        'payment_method': 'paymentMethod'
    }

    def __init__(self, destination=None, amount=None, payment_method=None):  # noqa: E501
        """CreatePayoutRequest - a model defined in Swagger"""  # noqa: E501
        self._destination = None
        self._amount = None
        self._payment_method = None
        self.discriminator = None
        if destination is not None:
            self.destination = destination
        if amount is not None:
            self.amount = amount
        if payment_method is not None:
            self.payment_method = payment_method

    @property
    def destination(self):
        """Gets the destination of this CreatePayoutRequest.  # noqa: E501

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :return: The destination of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this CreatePayoutRequest.

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :param destination: The destination of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def amount(self):
        """Gets the amount of this CreatePayoutRequest.  # noqa: E501

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :return: The amount of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CreatePayoutRequest.

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :param amount: The amount of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def payment_method(self):
        """Gets the payment_method of this CreatePayoutRequest.  # noqa: E501

        The payment method of the payout  # noqa: E501

        :return: The payment_method of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this CreatePayoutRequest.

        The payment method of the payout  # noqa: E501

        :param payment_method: The payment_method of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreatePayoutRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePayoutRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.models.application_server_info_node_status_data import ApplicationServerInfoNodeStatusData  # noqa: E501
from pygreenfield.rest import ApiException


class TestApplicationServerInfoNodeStatusData(unittest.TestCase):
    """ApplicationServerInfoNodeStatusData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApplicationServerInfoNodeStatusData(self):
        """Test ApplicationServerInfoNodeStatusData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.application_server_info_node_status_data.ApplicationServerInfoNodeStatusData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.api_keys_api import APIKeysApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_api_keys_apikey_delete(self):
        """Test case for api_v1_api_keys_apikey_delete

        Revoke an API Key  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_current_delete(self):
        """Test case for api_v1_api_keys_current_delete

        Revoke the current API Key  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_current_get(self):
        """Test case for api_v1_api_keys_current_get

        Get the current API Key information  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_post(self):
        """Test case for api_v1_api_keys_post

        Create a new API Key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TradeResultData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'from_asset': 'str',
        'to_asset': 'str',
        'ledger_entries': 'list[LedgerEntryData]',
        'trade_id': 'str',
        'account_id': 'str',
        'custodian_code': 'str'
    }

    attribute_map = {
        'from_asset': 'fromAsset',
        'to_asset': 'toAsset',
        'ledger_entries': 'ledgerEntries',
        'trade_id': 'tradeId',
        'account_id': 'accountId',
        'custodian_code': 'custodianCode'
    }

    def __init__(self, from_asset=None, to_asset=None, ledger_entries=None, trade_id=None, account_id=None, custodian_code=None):  # noqa: E501
        """TradeResultData - a model defined in Swagger"""  # noqa: E501
        self._from_asset = None
        self._to_asset = None
        self._ledger_entries = None
        self._trade_id = None
        self._account_id = None
        self._custodian_code = None
        self.discriminator = None
        if from_asset is not None:
            self.from_asset = from_asset
        if to_asset is not None:
            self.to_asset = to_asset
        if ledger_entries is not None:
            self.ledger_entries = ledger_entries
        if trade_id is not None:
            self.trade_id = trade_id
        if account_id is not None:
            self.account_id = account_id
        if custodian_code is not None:
            self.custodian_code = custodian_code

    @property
    def from_asset(self):
        """Gets the from_asset of this TradeResultData.  # noqa: E501

        The asset to trade.  # noqa: E501

        :return: The from_asset of this TradeResultData.  # noqa: E501
        :rtype: str
        """
        return self._from_asset

    @from_asset.setter
    def from_asset(self, from_asset):
        """Sets the from_asset of this TradeResultData.

        The asset to trade.  # noqa: E501

        :param from_asset: The from_asset of this TradeResultData.  # noqa: E501
        :type: str
        """

        self._from_asset = from_asset

    @property
    def to_asset(self):
        """Gets the to_asset of this TradeResultData.  # noqa: E501

        The asset you want.  # noqa: E501

        :return: The to_asset of this TradeResultData.  # noqa: E501
        :rtype: str
        """
        return self._to_asset

    @to_asset.setter
    def to_asset(self, to_asset):
        """Sets the to_asset of this TradeResultData.

        The asset you want.  # noqa: E501

        :param to_asset: The to_asset of this TradeResultData.  # noqa: E501
        :type: str
        """

        self._to_asset = to_asset

    @property
    def ledger_entries(self):
        """Gets the ledger_entries of this TradeResultData.  # noqa: E501

        The asset entries that were changed during the trade. This is an array of at least 2 items with the asset sold and the asset gained. It may also include ledger entries for the costs of the trade and possibly exchange tokens used.  # noqa: E501

        :return: The ledger_entries of this TradeResultData.  # noqa: E501
        :rtype: list[LedgerEntryData]
        """
        return self._ledger_entries

    @ledger_entries.setter
    def ledger_entries(self, ledger_entries):
        """Sets the ledger_entries of this TradeResultData.

        The asset entries that were changed during the trade. This is an array of at least 2 items with the asset sold and the asset gained. It may also include ledger entries for the costs of the trade and possibly exchange tokens used.  # noqa: E501

        :param ledger_entries: The ledger_entries of this TradeResultData.  # noqa: E501
        :type: list[LedgerEntryData]
        """

        self._ledger_entries = ledger_entries

    @property
    def trade_id(self):
        """Gets the trade_id of this TradeResultData.  # noqa: E501

        The unique ID of the trade used by the exchange. This ID can be used to get the details of this trade at a later time.  # noqa: E501

        :return: The trade_id of this TradeResultData.  # noqa: E501
        :rtype: str
        """
        return self._trade_id

    @trade_id.setter
    def trade_id(self, trade_id):
        """Sets the trade_id of this TradeResultData.

        The unique ID of the trade used by the exchange. This ID can be used to get the details of this trade at a later time.  # noqa: E501

        :param trade_id: The trade_id of this TradeResultData.  # noqa: E501
        :type: str
        """

        self._trade_id = trade_id

    @property
    def account_id(self):
        """Gets the account_id of this TradeResultData.  # noqa: E501

        The unique ID of the custodian account used.  # noqa: E501

        :return: The account_id of this TradeResultData.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this TradeResultData.

        The unique ID of the custodian account used.  # noqa: E501

        :param account_id: The account_id of this TradeResultData.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def custodian_code(self):
        """Gets the custodian_code of this TradeResultData.  # noqa: E501

        The code of the custodian used.  # noqa: E501

        :return: The custodian_code of this TradeResultData.  # noqa: E501
        :rtype: str
        """
        return self._custodian_code

    @custodian_code.setter
    def custodian_code(self, custodian_code):
        """Sets the custodian_code of this TradeResultData.

        The code of the custodian used.  # noqa: E501

        :param custodian_code: The custodian_code of this TradeResultData.  # noqa: E501
        :type: str
        """

        self._custodian_code = custodian_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TradeResultData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TradeResultData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from pygreenfield.models.invoice_data_base import InvoiceDataBase  # noqa: F401,E501

class InvoiceData(InvoiceDataBase):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'store_id': 'str',
        'amount': 'str',
        'currency': 'str',
        'type': 'InvoiceType',
        'checkout_link': 'str',
        'created_time': 'object',
        'expiration_time': 'object',
        'monitoring_time': 'object',
        'status': 'InvoiceStatus',
        'additional_status': 'InvoiceAdditionalStatus',
        'available_statuses_for_manual_marking': 'list[InvoiceStatus]',
        'archived': 'bool'
    }
    if hasattr(InvoiceDataBase, "swagger_types"):
        swagger_types.update(InvoiceDataBase.swagger_types)

    attribute_map = {
        'id': 'id',
        'store_id': 'storeId',
        'amount': 'amount',
        'currency': 'currency',
        'type': 'type',
        'checkout_link': 'checkoutLink',
        'created_time': 'createdTime',
        'expiration_time': 'expirationTime',
        'monitoring_time': 'monitoringTime',
        'status': 'status',
        'additional_status': 'additionalStatus',
        'available_statuses_for_manual_marking': 'availableStatusesForManualMarking',
        'archived': 'archived'
    }
    if hasattr(InvoiceDataBase, "attribute_map"):
        attribute_map.update(InvoiceDataBase.attribute_map)

    def __init__(self, id=None, store_id=None, amount=None, currency=None, type=None, checkout_link=None, created_time=None, expiration_time=None, monitoring_time=None, status=None, additional_status=None, available_statuses_for_manual_marking=None, archived=None, *args, **kwargs):  # noqa: E501
        """InvoiceData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._store_id = None
        self._amount = None
        self._currency = None
        self._type = None
        self._checkout_link = None
        self._created_time = None
        self._expiration_time = None
        self._monitoring_time = None
        self._status = None
        self._additional_status = None
        self._available_statuses_for_manual_marking = None
        self._archived = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if store_id is not None:
            self.store_id = store_id
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if type is not None:
            self.type = type
        if checkout_link is not None:
            self.checkout_link = checkout_link
        if created_time is not None:
            self.created_time = created_time
        if expiration_time is not None:
            self.expiration_time = expiration_time
        if monitoring_time is not None:
            self.monitoring_time = monitoring_time
        if status is not None:
            self.status = status
        if additional_status is not None:
            self.additional_status = additional_status
        if available_statuses_for_manual_marking is not None:
            self.available_statuses_for_manual_marking = available_statuses_for_manual_marking
        if archived is not None:
            self.archived = archived
        InvoiceDataBase.__init__(self, *args, **kwargs)

    @property
    def id(self):
        """Gets the id of this InvoiceData.  # noqa: E501

        The identifier of the invoice  # noqa: E501

        :return: The id of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceData.

        The identifier of the invoice  # noqa: E501

        :param id: The id of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def store_id(self):
        """Gets the store_id of this InvoiceData.  # noqa: E501

        The store identifier that the invoice belongs to  # noqa: E501

        :return: The store_id of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._store_id

    @store_id.setter
    def store_id(self, store_id):
        """Sets the store_id of this InvoiceData.

        The store identifier that the invoice belongs to  # noqa: E501

        :param store_id: The store_id of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._store_id = store_id

    @property
    def amount(self):
        """Gets the amount of this InvoiceData.  # noqa: E501

        The amount of the invoice  # noqa: E501

        :return: The amount of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceData.

        The amount of the invoice  # noqa: E501

        :param amount: The amount of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InvoiceData.  # noqa: E501

        The currency of the invoice  # noqa: E501

        :return: The currency of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceData.

        The currency of the invoice  # noqa: E501

        :param currency: The currency of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def type(self):
        """Gets the type of this InvoiceData.  # noqa: E501


        :return: The type of this InvoiceData.  # noqa: E501
        :rtype: InvoiceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InvoiceData.


        :param type: The type of this InvoiceData.  # noqa: E501
        :type: InvoiceType
        """

        self._type = type

    @property
    def checkout_link(self):
        """Gets the checkout_link of this InvoiceData.  # noqa: E501

        The link to the checkout page, where you can redirect the customer  # noqa: E501

        :return: The checkout_link of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._checkout_link

    @checkout_link.setter
    def checkout_link(self, checkout_link):
        """Sets the checkout_link of this InvoiceData.

        The link to the checkout page, where you can redirect the customer  # noqa: E501

        :param checkout_link: The checkout_link of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._checkout_link = checkout_link

    @property
    def created_time(self):
        """Gets the created_time of this InvoiceData.  # noqa: E501

        The creation time of the invoice  # noqa: E501

        :return: The created_time of this InvoiceData.  # noqa: E501
        :rtype: object
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this InvoiceData.

        The creation time of the invoice  # noqa: E501

        :param created_time: The created_time of this InvoiceData.  # noqa: E501
        :type: object
        """

        self._created_time = created_time

    @property
    def expiration_time(self):
        """Gets the expiration_time of this InvoiceData.  # noqa: E501

        The expiration time of the invoice  # noqa: E501

        :return: The expiration_time of this InvoiceData.  # noqa: E501
        :rtype: object
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this InvoiceData.

        The expiration time of the invoice  # noqa: E501

        :param expiration_time: The expiration_time of this InvoiceData.  # noqa: E501
        :type: object
        """

        self._expiration_time = expiration_time

    @property
    def monitoring_time(self):
        """Gets the monitoring_time of this InvoiceData.  # noqa: E501

        The monitoring time of the invoice  # noqa: E501

        :return: The monitoring_time of this InvoiceData.  # noqa: E501
        :rtype: object
        """
        return self._monitoring_time

    @monitoring_time.setter
    def monitoring_time(self, monitoring_time):
        """Sets the monitoring_time of this InvoiceData.

        The monitoring time of the invoice  # noqa: E501

        :param monitoring_time: The monitoring_time of this InvoiceData.  # noqa: E501
        :type: object
        """

        self._monitoring_time = monitoring_time

    @property
    def status(self):
        """Gets the status of this InvoiceData.  # noqa: E501


        :return: The status of this InvoiceData.  # noqa: E501
        :rtype: InvoiceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InvoiceData.


        :param status: The status of this InvoiceData.  # noqa: E501
        :type: InvoiceStatus
        """

        self._status = status

    @property
    def additional_status(self):
        """Gets the additional_status of this InvoiceData.  # noqa: E501


        :return: The additional_status of this InvoiceData.  # noqa: E501
        :rtype: InvoiceAdditionalStatus
        """
        return self._additional_status

    @additional_status.setter
    def additional_status(self, additional_status):
        """Sets the additional_status of this InvoiceData.


        :param additional_status: The additional_status of this InvoiceData.  # noqa: E501
        :type: InvoiceAdditionalStatus
        """

        self._additional_status = additional_status

    @property
    def available_statuses_for_manual_marking(self):
        """Gets the available_statuses_for_manual_marking of this InvoiceData.  # noqa: E501

        The statuses the invoice can be manually marked as  # noqa: E501

        :return: The available_statuses_for_manual_marking of this InvoiceData.  # noqa: E501
        :rtype: list[InvoiceStatus]
        """
        return self._available_statuses_for_manual_marking

    @available_statuses_for_manual_marking.setter
    def available_statuses_for_manual_marking(self, available_statuses_for_manual_marking):
        """Sets the available_statuses_for_manual_marking of this InvoiceData.

        The statuses the invoice can be manually marked as  # noqa: E501

        :param available_statuses_for_manual_marking: The available_statuses_for_manual_marking of this InvoiceData.  # noqa: E501
        :type: list[InvoiceStatus]
        """

        self._available_statuses_for_manual_marking = available_statuses_for_manual_marking

    @property
    def archived(self):
        """Gets the archived of this InvoiceData.  # noqa: E501

        true if the invoice is archived  # noqa: E501

        :return: The archived of this InvoiceData.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this InvoiceData.

        true if the invoice is archived  # noqa: E501

        :param archived: The archived of this InvoiceData.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoiceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NotificationData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'body': 'str',
        'link': 'str',
        'created_time': 'AllOfNotificationDataCreatedTime',
        'seen': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'body': 'body',
        'link': 'link',
        'created_time': 'createdTime',
        'seen': 'seen'
    }

    def __init__(self, id=None, body=None, link=None, created_time=None, seen=None):  # noqa: E501
        """NotificationData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._body = None
        self._link = None
        self._created_time = None
        self._seen = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if body is not None:
            self.body = body
        if link is not None:
            self.link = link
        if created_time is not None:
            self.created_time = created_time
        if seen is not None:
            self.seen = seen

    @property
    def id(self):
        """Gets the id of this NotificationData.  # noqa: E501

        The identifier of the notification  # noqa: E501

        :return: The id of this NotificationData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NotificationData.

        The identifier of the notification  # noqa: E501

        :param id: The id of this NotificationData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def body(self):
        """Gets the body of this NotificationData.  # noqa: E501

        The html body of the notifications  # noqa: E501

        :return: The body of this NotificationData.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this NotificationData.

        The html body of the notifications  # noqa: E501

        :param body: The body of this NotificationData.  # noqa: E501
        :type: str
        """

        self._body = body

    @property
    def link(self):
        """Gets the link of this NotificationData.  # noqa: E501

        The link of the notification  # noqa: E501

        :return: The link of this NotificationData.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this NotificationData.

        The link of the notification  # noqa: E501

        :param link: The link of this NotificationData.  # noqa: E501
        :type: str
        """

        self._link = link

    @property
    def created_time(self):
        """Gets the created_time of this NotificationData.  # noqa: E501

        The creation time of the notification  # noqa: E501

        :return: The created_time of this NotificationData.  # noqa: E501
        :rtype: AllOfNotificationDataCreatedTime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this NotificationData.

        The creation time of the notification  # noqa: E501

        :param created_time: The created_time of this NotificationData.  # noqa: E501
        :type: AllOfNotificationDataCreatedTime
        """

        self._created_time = created_time

    @property
    def seen(self):
        """Gets the seen of this NotificationData.  # noqa: E501

        If the notification has been seen by the user  # noqa: E501

        :return: The seen of this NotificationData.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this NotificationData.

        If the notification has been seen by the user  # noqa: E501

        :param seen: The seen of this NotificationData.  # noqa: E501
        :type: bool
        """

        self._seen = seen

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'delivery_id': 'str',
        'webhook_id': 'str',
        'original_delivery_id': 'str',
        'is_redelivery': 'bool',
        'type': 'str',
        'timestamp': 'AllOfWebhookEventTimestamp'
    }

    attribute_map = {
        'delivery_id': 'deliveryId',
        'webhook_id': 'webhookId',
        'original_delivery_id': 'originalDeliveryId',
        'is_redelivery': 'isRedelivery',
        'type': 'type',
        'timestamp': 'timestamp'
    }

    def __init__(self, delivery_id=None, webhook_id=None, original_delivery_id=None, is_redelivery=None, type=None, timestamp=None):  # noqa: E501
        """WebhookEvent - a model defined in Swagger"""  # noqa: E501
        self._delivery_id = None
        self._webhook_id = None
        self._original_delivery_id = None
        self._is_redelivery = None
        self._type = None
        self._timestamp = None
        self.discriminator = None
        if delivery_id is not None:
            self.delivery_id = delivery_id
        if webhook_id is not None:
            self.webhook_id = webhook_id
        if original_delivery_id is not None:
            self.original_delivery_id = original_delivery_id
        if is_redelivery is not None:
            self.is_redelivery = is_redelivery
        if type is not None:
            self.type = type
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def delivery_id(self):
        """Gets the delivery_id of this WebhookEvent.  # noqa: E501

        The delivery id of the webhook  # noqa: E501

        :return: The delivery_id of this WebhookEvent.  # noqa: E501
        :rtype: str
        """
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, delivery_id):
        """Sets the delivery_id of this WebhookEvent.

        The delivery id of the webhook  # noqa: E501

        :param delivery_id: The delivery_id of this WebhookEvent.  # noqa: E501
        :type: str
        """

        self._delivery_id = delivery_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookEvent.  # noqa: E501

        The id of the webhook  # noqa: E501

        :return: The webhook_id of this WebhookEvent.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookEvent.

        The id of the webhook  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookEvent.  # noqa: E501
        :type: str
        """

        self._webhook_id = webhook_id

    @property
    def original_delivery_id(self):
        """Gets the original_delivery_id of this WebhookEvent.  # noqa: E501

        If this delivery is a redelivery, the is the delivery id of the original delivery.  # noqa: E501

        :return: The original_delivery_id of this WebhookEvent.  # noqa: E501
        :rtype: str
        """
        return self._original_delivery_id

    @original_delivery_id.setter
    def original_delivery_id(self, original_delivery_id):
        """Sets the original_delivery_id of this WebhookEvent.

        If this delivery is a redelivery, the is the delivery id of the original delivery.  # noqa: E501

        :param original_delivery_id: The original_delivery_id of this WebhookEvent.  # noqa: E501
        :type: str
        """

        self._original_delivery_id = original_delivery_id

    @property
    def is_redelivery(self):
        """Gets the is_redelivery of this WebhookEvent.  # noqa: E501

        True if this delivery is a redelivery  # noqa: E501

        :return: The is_redelivery of this WebhookEvent.  # noqa: E501
        :rtype: bool
        """
        return self._is_redelivery

    @is_redelivery.setter
    def is_redelivery(self, is_redelivery):
        """Sets the is_redelivery of this WebhookEvent.

        True if this delivery is a redelivery  # noqa: E501

        :param is_redelivery: The is_redelivery of this WebhookEvent.  # noqa: E501
        :type: bool
        """

        self._is_redelivery = is_redelivery

    @property
    def type(self):
        """Gets the type of this WebhookEvent.  # noqa: E501

        The type of this event, current available are `InvoiceCreated`, `InvoiceReceivedPayment`, `InvoiceProcessing`, `InvoiceExpired`, `InvoiceSettled`, `InvoiceInvalid`, and `InvoicePaymentSettled`.  # noqa: E501

        :return: The type of this WebhookEvent.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WebhookEvent.

        The type of this event, current available are `InvoiceCreated`, `InvoiceReceivedPayment`, `InvoiceProcessing`, `InvoiceExpired`, `InvoiceSettled`, `InvoiceInvalid`, and `InvoicePaymentSettled`.  # noqa: E501

        :param type: The type of this WebhookEvent.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def timestamp(self):
        """Gets the timestamp of this WebhookEvent.  # noqa: E501

        The timestamp when this delivery has been created  # noqa: E501

        :return: The timestamp of this WebhookEvent.  # noqa: E501
        :rtype: AllOfWebhookEventTimestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this WebhookEvent.

        The timestamp when this delivery has been created  # noqa: E501

        :param timestamp: The timestamp of this WebhookEvent.  # noqa: E501
        :type: AllOfWebhookEventTimestamp
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores_api import StoresApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresApi(unittest.TestCase):
    """StoresApi unit test stubs"""

    def setUp(self):
        self.api = StoresApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_post(self):
        """Test case for api_v1_stores_post

        Create a new store  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_delete(self):
        """Test case for api_v1_stores_store_id_delete

        Remove Store  # noqa: E501
        """
        pass

    def test_stores_get_store(self):
        """Test case for stores_get_store

        Get store  # noqa: E501
        """
        pass

    def test_stores_get_stores(self):
        """Test case for stores_get_stores

        Get stores  # noqa: E501
        """
        pass

    def test_stores_update_store(self):
        """Test case for stores_update_store

        Update store  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pygreenfield.api.api_keys_api import APIKeysApi
from pygreenfield.api.apps_api import AppsApi
from pygreenfield.api.authorization_api import AuthorizationApi
from pygreenfield.api.custodians_api import CustodiansApi
from pygreenfield.api.health_api import HealthApi
from pygreenfield.api.invoices_api import InvoicesApi
from pygreenfield.api.lightning__internal_node_api import LightningInternalNodeApi
from pygreenfield.api.lightning__store_api import LightningStoreApi
from pygreenfield.api.miscelleneous_api import MiscelleneousApi
from pygreenfield.api.notifications__current_user_api import NotificationsCurrentUserApi
from pygreenfield.api.payment_requests_api import PaymentRequestsApi
from pygreenfield.api.payout_processors_api import PayoutProcessorsApi
from pygreenfield.api.pull_payments__management_api import PullPaymentsManagementApi
from pygreenfield.api.pull_payments__public_api import PullPaymentsPublicApi
from pygreenfield.api.pull_payments_payout__public_api import PullPaymentsPayoutPublicApi
from pygreenfield.api.server_info_api import ServerInfoApi
from pygreenfield.api.store_payment_methods_api import StorePaymentMethodsApi
from pygreenfield.api.store_payment_methods__lnurl_pay_api import StorePaymentMethodsLNURLPayApi
from pygreenfield.api.store_payment_methods__lightning_network_api import StorePaymentMethodsLightningNetworkApi
from pygreenfield.api.store_payment_methods__on_chain_api import StorePaymentMethodsOnChainApi
from pygreenfield.api.store_wallet__on_chain_api import StoreWalletOnChainApi
from pygreenfield.api.stores_api import StoresApi
from pygreenfield.api.stores__email_api import StoresEmailApi
from pygreenfield.api.stores__payout_processors_api import StoresPayoutProcessorsApi
from pygreenfield.api.stores__payouts_api import StoresPayoutsApi
from pygreenfield.api.stores__users_api import StoresUsersApi
from pygreenfield.api.users_api import UsersApi
from pygreenfield.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentRequestBaseData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'str',
        'title': 'str',
        'currency': 'str',
        'email': 'str',
        'description': 'str',
        'expiry_date': 'AllOfPaymentRequestBaseDataExpiryDate',
        'embedded_css': 'str',
        'custom_css_link': 'str',
        'allow_custom_payment_amounts': 'bool'
    }

    attribute_map = {
        'amount': 'amount',
        'title': 'title',
        'currency': 'currency',
        'email': 'email',
        'description': 'description',
        'expiry_date': 'expiryDate',
        'embedded_css': 'embeddedCSS',
        'custom_css_link': 'customCSSLink',
        'allow_custom_payment_amounts': 'allowCustomPaymentAmounts'
    }

    def __init__(self, amount=None, title=None, currency=None, email=None, description=None, expiry_date=None, embedded_css=None, custom_css_link=None, allow_custom_payment_amounts=None):  # noqa: E501
        """PaymentRequestBaseData - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._title = None
        self._currency = None
        self._email = None
        self._description = None
        self._expiry_date = None
        self._embedded_css = None
        self._custom_css_link = None
        self._allow_custom_payment_amounts = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if title is not None:
            self.title = title
        if currency is not None:
            self.currency = currency
        if email is not None:
            self.email = email
        if description is not None:
            self.description = description
        if expiry_date is not None:
            self.expiry_date = expiry_date
        if embedded_css is not None:
            self.embedded_css = embedded_css
        if custom_css_link is not None:
            self.custom_css_link = custom_css_link
        if allow_custom_payment_amounts is not None:
            self.allow_custom_payment_amounts = allow_custom_payment_amounts

    @property
    def amount(self):
        """Gets the amount of this PaymentRequestBaseData.  # noqa: E501

        The amount of the payment request  # noqa: E501

        :return: The amount of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentRequestBaseData.

        The amount of the payment request  # noqa: E501

        :param amount: The amount of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def title(self):
        """Gets the title of this PaymentRequestBaseData.  # noqa: E501

        The title of the payment request  # noqa: E501

        :return: The title of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PaymentRequestBaseData.

        The title of the payment request  # noqa: E501

        :param title: The title of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def currency(self):
        """Gets the currency of this PaymentRequestBaseData.  # noqa: E501

        The currency of the payment request. If empty, the store's default currency code will be used.  # noqa: E501

        :return: The currency of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PaymentRequestBaseData.

        The currency of the payment request. If empty, the store's default currency code will be used.  # noqa: E501

        :param currency: The currency of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def email(self):
        """Gets the email of this PaymentRequestBaseData.  # noqa: E501

        The email used in invoices generated by the payment request  # noqa: E501

        :return: The email of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PaymentRequestBaseData.

        The email used in invoices generated by the payment request  # noqa: E501

        :param email: The email of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def description(self):
        """Gets the description of this PaymentRequestBaseData.  # noqa: E501

        The description of the payment request  # noqa: E501

        :return: The description of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentRequestBaseData.

        The description of the payment request  # noqa: E501

        :param description: The description of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expiry_date(self):
        """Gets the expiry_date of this PaymentRequestBaseData.  # noqa: E501

        The expiry date of the payment request  # noqa: E501

        :return: The expiry_date of this PaymentRequestBaseData.  # noqa: E501
        :rtype: AllOfPaymentRequestBaseDataExpiryDate
        """
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, expiry_date):
        """Sets the expiry_date of this PaymentRequestBaseData.

        The expiry date of the payment request  # noqa: E501

        :param expiry_date: The expiry_date of this PaymentRequestBaseData.  # noqa: E501
        :type: AllOfPaymentRequestBaseDataExpiryDate
        """

        self._expiry_date = expiry_date

    @property
    def embedded_css(self):
        """Gets the embedded_css of this PaymentRequestBaseData.  # noqa: E501

        Custom CSS styling for the payment request  # noqa: E501

        :return: The embedded_css of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._embedded_css

    @embedded_css.setter
    def embedded_css(self, embedded_css):
        """Sets the embedded_css of this PaymentRequestBaseData.

        Custom CSS styling for the payment request  # noqa: E501

        :param embedded_css: The embedded_css of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._embedded_css = embedded_css

    @property
    def custom_css_link(self):
        """Gets the custom_css_link of this PaymentRequestBaseData.  # noqa: E501

        Custom CSS link for styling the payment request  # noqa: E501

        :return: The custom_css_link of this PaymentRequestBaseData.  # noqa: E501
        :rtype: str
        """
        return self._custom_css_link

    @custom_css_link.setter
    def custom_css_link(self, custom_css_link):
        """Sets the custom_css_link of this PaymentRequestBaseData.

        Custom CSS link for styling the payment request  # noqa: E501

        :param custom_css_link: The custom_css_link of this PaymentRequestBaseData.  # noqa: E501
        :type: str
        """

        self._custom_css_link = custom_css_link

    @property
    def allow_custom_payment_amounts(self):
        """Gets the allow_custom_payment_amounts of this PaymentRequestBaseData.  # noqa: E501

        Whether to allow users to create invoices that partially pay the payment request   # noqa: E501

        :return: The allow_custom_payment_amounts of this PaymentRequestBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._allow_custom_payment_amounts

    @allow_custom_payment_amounts.setter
    def allow_custom_payment_amounts(self, allow_custom_payment_amounts):
        """Sets the allow_custom_payment_amounts of this PaymentRequestBaseData.

        Whether to allow users to create invoices that partially pay the payment request   # noqa: E501

        :param allow_custom_payment_amounts: The allow_custom_payment_amounts of this PaymentRequestBaseData.  # noqa: E501
        :type: bool
        """

        self._allow_custom_payment_amounts = allow_custom_payment_amounts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentRequestBaseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestBaseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookDataBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'enabled': 'bool',
        'automatic_redelivery': 'bool',
        'url': 'str',
        'authorized_events': 'WebhookDataBaseAuthorizedEvents'
    }

    attribute_map = {
        'id': 'id',
        'enabled': 'enabled',
        'automatic_redelivery': 'automaticRedelivery',
        'url': 'url',
        'authorized_events': 'authorizedEvents'
    }

    def __init__(self, id=None, enabled=True, automatic_redelivery=True, url=None, authorized_events=None):  # noqa: E501
        """WebhookDataBase - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._enabled = None
        self._automatic_redelivery = None
        self._url = None
        self._authorized_events = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if enabled is not None:
            self.enabled = enabled
        if automatic_redelivery is not None:
            self.automatic_redelivery = automatic_redelivery
        if url is not None:
            self.url = url
        if authorized_events is not None:
            self.authorized_events = authorized_events

    @property
    def id(self):
        """Gets the id of this WebhookDataBase.  # noqa: E501

        The id of the webhook  # noqa: E501

        :return: The id of this WebhookDataBase.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDataBase.

        The id of the webhook  # noqa: E501

        :param id: The id of this WebhookDataBase.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def enabled(self):
        """Gets the enabled of this WebhookDataBase.  # noqa: E501

        Whether this webhook is enabled or not  # noqa: E501

        :return: The enabled of this WebhookDataBase.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this WebhookDataBase.

        Whether this webhook is enabled or not  # noqa: E501

        :param enabled: The enabled of this WebhookDataBase.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def automatic_redelivery(self):
        """Gets the automatic_redelivery of this WebhookDataBase.  # noqa: E501

        If true, BTCPay Server will retry to redeliver any failed delivery after 10 seconds, 1 minutes and up to 6 times after 10 minutes.  # noqa: E501

        :return: The automatic_redelivery of this WebhookDataBase.  # noqa: E501
        :rtype: bool
        """
        return self._automatic_redelivery

    @automatic_redelivery.setter
    def automatic_redelivery(self, automatic_redelivery):
        """Sets the automatic_redelivery of this WebhookDataBase.

        If true, BTCPay Server will retry to redeliver any failed delivery after 10 seconds, 1 minutes and up to 6 times after 10 minutes.  # noqa: E501

        :param automatic_redelivery: The automatic_redelivery of this WebhookDataBase.  # noqa: E501
        :type: bool
        """

        self._automatic_redelivery = automatic_redelivery

    @property
    def url(self):
        """Gets the url of this WebhookDataBase.  # noqa: E501

        The endpoint where BTCPay Server will make the POST request with the webhook body  # noqa: E501

        :return: The url of this WebhookDataBase.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookDataBase.

        The endpoint where BTCPay Server will make the POST request with the webhook body  # noqa: E501

        :param url: The url of this WebhookDataBase.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def authorized_events(self):
        """Gets the authorized_events of this WebhookDataBase.  # noqa: E501


        :return: The authorized_events of this WebhookDataBase.  # noqa: E501
        :rtype: WebhookDataBaseAuthorizedEvents
        """
        return self._authorized_events

    @authorized_events.setter
    def authorized_events(self, authorized_events):
        """Sets the authorized_events of this WebhookDataBase.


        :param authorized_events: The authorized_events of this WebhookDataBase.  # noqa: E501
        :type: WebhookDataBaseAuthorizedEvents
        """

        self._authorized_events = authorized_events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookDataBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDataBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_payment_methods__lnurl_pay_api import StorePaymentMethodsLNURLPayApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStorePaymentMethodsLNURLPayApi(unittest.TestCase):
    """StorePaymentMethodsLNURLPayApi unit test stubs"""

    def setUp(self):
        self.api = StorePaymentMethodsLNURLPayApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete(self):
        """Test case for api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete

        Remove store LNURL Pay payment method  # noqa: E501
        """
        pass

    def test_store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method(self):
        """Test case for store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method

        Get store LNURL Pay payment method  # noqa: E501
        """
        pass

    def test_store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods(self):
        """Test case for store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods

        Get store LNURL payment methods  # noqa: E501
        """
        pass

    def test_store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method(self):
        """Test case for store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method

        Update store LNURL Pay payment method  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class StorePaymentMethodsLNURLPayApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Remove store LNURL Pay payment method  # noqa: E501

        Removes the specified store payment method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to update (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Remove store LNURL Pay payment method  # noqa: E501

        Removes the specified store payment method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to update (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store LNURL Pay payment method  # noqa: E501

        View information about the specified payment method  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: LNURLPayPaymentMethodData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store LNURL Pay payment method  # noqa: E501

        View information about the specified payment method  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: LNURLPayPaymentMethodData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LNURLPayPaymentMethodData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods(self, store_id, **kwargs):  # noqa: E501
        """Get store LNURL payment methods  # noqa: E501

        View information about the stores' configured LNURL payment methods  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param bool enabled: Fetch payment methods that are enabled/disabled only
        :return: LNURLPayPaymentMethodDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods_with_http_info(store_id, **kwargs)  # noqa: E501
        else:
            (data) = self.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods_with_http_info(store_id, **kwargs)  # noqa: E501
            return data

    def store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods_with_http_info(self, store_id, **kwargs):  # noqa: E501
        """Get store LNURL payment methods  # noqa: E501

        View information about the stores' configured LNURL payment methods  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods_with_http_info(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param bool enabled: Fetch payment methods that are enabled/disabled only
        :return: LNURLPayPaymentMethodDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'enabled']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501

        query_params = []
        if 'enabled' in params:
            query_params.append(('enabled', params['enabled']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/LNURL', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LNURLPayPaymentMethodDataList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method(self, body, store_id, crypto_code, **kwargs):  # noqa: E501
        """Update store LNURL Pay payment method  # noqa: E501

        Update the specified store's payment method  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method(body, store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LNURLPayPaymentMethodData body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to update (required)
        :return: LNURLPayPaymentMethodData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method_with_http_info(body, store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method_with_http_info(body, store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method_with_http_info(self, body, store_id, crypto_code, **kwargs):  # noqa: E501
        """Update store LNURL Pay payment method  # noqa: E501

        Update the specified store's payment method  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method_with_http_info(body, store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LNURLPayPaymentMethodData body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to update (required)
        :return: LNURLPayPaymentMethodData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LNURLPayPaymentMethodData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EmailSettingsData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'server': 'str',
        'port': 'float',
        'login': 'str',
        'password': 'str',
        '_from': 'str',
        'from_display': 'str'
    }

    attribute_map = {
        'server': 'server',
        'port': 'port',
        'login': 'login',
        'password': 'password',
        '_from': 'from',
        'from_display': 'fromDisplay'
    }

    def __init__(self, server=None, port=None, login=None, password=None, _from=None, from_display=None):  # noqa: E501
        """EmailSettingsData - a model defined in Swagger"""  # noqa: E501
        self._server = None
        self._port = None
        self._login = None
        self._password = None
        self.__from = None
        self._from_display = None
        self.discriminator = None
        if server is not None:
            self.server = server
        if port is not None:
            self.port = port
        if login is not None:
            self.login = login
        if password is not None:
            self.password = password
        if _from is not None:
            self._from = _from
        if from_display is not None:
            self.from_display = from_display

    @property
    def server(self):
        """Gets the server of this EmailSettingsData.  # noqa: E501

        Smtp server host  # noqa: E501

        :return: The server of this EmailSettingsData.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this EmailSettingsData.

        Smtp server host  # noqa: E501

        :param server: The server of this EmailSettingsData.  # noqa: E501
        :type: str
        """

        self._server = server

    @property
    def port(self):
        """Gets the port of this EmailSettingsData.  # noqa: E501

        Smtp server port  # noqa: E501

        :return: The port of this EmailSettingsData.  # noqa: E501
        :rtype: float
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this EmailSettingsData.

        Smtp server port  # noqa: E501

        :param port: The port of this EmailSettingsData.  # noqa: E501
        :type: float
        """

        self._port = port

    @property
    def login(self):
        """Gets the login of this EmailSettingsData.  # noqa: E501

        Smtp server username  # noqa: E501

        :return: The login of this EmailSettingsData.  # noqa: E501
        :rtype: str
        """
        return self._login

    @login.setter
    def login(self, login):
        """Sets the login of this EmailSettingsData.

        Smtp server username  # noqa: E501

        :param login: The login of this EmailSettingsData.  # noqa: E501
        :type: str
        """

        self._login = login

    @property
    def password(self):
        """Gets the password of this EmailSettingsData.  # noqa: E501

        Smtp server password  # noqa: E501

        :return: The password of this EmailSettingsData.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this EmailSettingsData.

        Smtp server password  # noqa: E501

        :param password: The password of this EmailSettingsData.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def _from(self):
        """Gets the _from of this EmailSettingsData.  # noqa: E501

        Email to send from  # noqa: E501

        :return: The _from of this EmailSettingsData.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmailSettingsData.

        Email to send from  # noqa: E501

        :param _from: The _from of this EmailSettingsData.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def from_display(self):
        """Gets the from_display of this EmailSettingsData.  # noqa: E501

        The name of the sender  # noqa: E501

        :return: The from_display of this EmailSettingsData.  # noqa: E501
        :rtype: str
        """
        return self._from_display

    @from_display.setter
    def from_display(self, from_display):
        """Sets the from_display of this EmailSettingsData.

        The name of the sender  # noqa: E501

        :param from_display: The from_display of this EmailSettingsData.  # noqa: E501
        :type: str
        """

        self._from_display = from_display

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailSettingsData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailSettingsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.models.v1_users_body import V1UsersBody  # noqa: E501
from pygreenfield.rest import ApiException


class TestV1UsersBody(unittest.TestCase):
    """V1UsersBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1UsersBody(self):
        """Test V1UsersBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.v1_users_body.V1UsersBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_payment_methods__lightning_network_api import StorePaymentMethodsLightningNetworkApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStorePaymentMethodsLightningNetworkApi(unittest.TestCase):
    """StorePaymentMethodsLightningNetworkApi unit test stubs"""

    def setUp(self):
        self.api = StorePaymentMethodsLightningNetworkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete(self):
        """Test case for api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete

        Remove store Lightning Network payment method  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_get_lightning_network_payment_method(self):
        """Test case for store_lightning_network_payment_methods_get_lightning_network_payment_method

        Get store Lightning Network payment method  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_get_lightning_network_payment_methods(self):
        """Test case for store_lightning_network_payment_methods_get_lightning_network_payment_methods

        Get store Lightning Network payment methods  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_update_lightning_network_payment_method(self):
        """Test case for store_lightning_network_payment_methods_update_lightning_network_payment_method

        Update store Lightning Network payment method  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.invoices_api import InvoicesApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestInvoicesApi(unittest.TestCase):
    """InvoicesApi unit test stubs"""

    def setUp(self):
        self.api = InvoicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_invoices_activate_payment_method(self):
        """Test case for invoices_activate_payment_method

        Activate Payment Method  # noqa: E501
        """
        pass

    def test_invoices_archive_invoice(self):
        """Test case for invoices_archive_invoice

        Archive invoice  # noqa: E501
        """
        pass

    def test_invoices_create_invoice(self):
        """Test case for invoices_create_invoice

        Create a new invoice  # noqa: E501
        """
        pass

    def test_invoices_get_invoice(self):
        """Test case for invoices_get_invoice

        Get invoice  # noqa: E501
        """
        pass

    def test_invoices_get_invoice_payment_methods(self):
        """Test case for invoices_get_invoice_payment_methods

        Get invoice payment methods  # noqa: E501
        """
        pass

    def test_invoices_get_invoices(self):
        """Test case for invoices_get_invoices

        Get invoices  # noqa: E501
        """
        pass

    def test_invoices_mark_invoice_status(self):
        """Test case for invoices_mark_invoice_status

        Mark invoice status  # noqa: E501
        """
        pass

    def test_invoices_unarchive_invoice(self):
        """Test case for invoices_unarchive_invoice

        Unarchive invoice  # noqa: E501
        """
        pass

    def test_invoices_update_invoice(self):
        """Test case for invoices_update_invoice

        Update invoice  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.payment_requests_api import PaymentRequestsApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestPaymentRequestsApi(unittest.TestCase):
    """PaymentRequestsApi unit test stubs"""

    def setUp(self):
        self.api = PaymentRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_payment_requests_archive_payment_request(self):
        """Test case for payment_requests_archive_payment_request

        Archive payment request  # noqa: E501
        """
        pass

    def test_payment_requests_create_payment_request(self):
        """Test case for payment_requests_create_payment_request

        Create a new payment request  # noqa: E501
        """
        pass

    def test_payment_requests_get_payment_request(self):
        """Test case for payment_requests_get_payment_request

        Get payment request  # noqa: E501
        """
        pass

    def test_payment_requests_get_payment_requests(self):
        """Test case for payment_requests_get_payment_requests

        Get payment requests  # noqa: E501
        """
        pass

    def test_payment_requests_update_payment_request(self):
        """Test case for payment_requests_update_payment_request

        Update payment request  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningPaymentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'status': 'LightningPaymentStatus',
        'bolt11': 'str',
        'payment_hash': 'str',
        'preimage': 'str',
        'created_at': 'AllOfLightningPaymentDataCreatedAt',
        'total_amount': 'str',
        'fee_amount': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'bolt11': 'BOLT11',
        'payment_hash': 'paymentHash',
        'preimage': 'preimage',
        'created_at': 'createdAt',
        'total_amount': 'totalAmount',
        'fee_amount': 'feeAmount'
    }

    def __init__(self, id=None, status=None, bolt11=None, payment_hash=None, preimage=None, created_at=None, total_amount=None, fee_amount=None):  # noqa: E501
        """LightningPaymentData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._status = None
        self._bolt11 = None
        self._payment_hash = None
        self._preimage = None
        self._created_at = None
        self._total_amount = None
        self._fee_amount = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if bolt11 is not None:
            self.bolt11 = bolt11
        if payment_hash is not None:
            self.payment_hash = payment_hash
        if preimage is not None:
            self.preimage = preimage
        if created_at is not None:
            self.created_at = created_at
        if total_amount is not None:
            self.total_amount = total_amount
        if fee_amount is not None:
            self.fee_amount = fee_amount

    @property
    def id(self):
        """Gets the id of this LightningPaymentData.  # noqa: E501

        The payment's ID  # noqa: E501

        :return: The id of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LightningPaymentData.

        The payment's ID  # noqa: E501

        :param id: The id of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this LightningPaymentData.  # noqa: E501


        :return: The status of this LightningPaymentData.  # noqa: E501
        :rtype: LightningPaymentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LightningPaymentData.


        :param status: The status of this LightningPaymentData.  # noqa: E501
        :type: LightningPaymentStatus
        """

        self._status = status

    @property
    def bolt11(self):
        """Gets the bolt11 of this LightningPaymentData.  # noqa: E501

        The BOLT11 representation of the payment  # noqa: E501

        :return: The bolt11 of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._bolt11

    @bolt11.setter
    def bolt11(self, bolt11):
        """Sets the bolt11 of this LightningPaymentData.

        The BOLT11 representation of the payment  # noqa: E501

        :param bolt11: The bolt11 of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._bolt11 = bolt11

    @property
    def payment_hash(self):
        """Gets the payment_hash of this LightningPaymentData.  # noqa: E501

        The payment hash  # noqa: E501

        :return: The payment_hash of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._payment_hash

    @payment_hash.setter
    def payment_hash(self, payment_hash):
        """Sets the payment_hash of this LightningPaymentData.

        The payment hash  # noqa: E501

        :param payment_hash: The payment_hash of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._payment_hash = payment_hash

    @property
    def preimage(self):
        """Gets the preimage of this LightningPaymentData.  # noqa: E501

        The payment preimage (available when status is complete)  # noqa: E501

        :return: The preimage of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._preimage

    @preimage.setter
    def preimage(self, preimage):
        """Sets the preimage of this LightningPaymentData.

        The payment preimage (available when status is complete)  # noqa: E501

        :param preimage: The preimage of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._preimage = preimage

    @property
    def created_at(self):
        """Gets the created_at of this LightningPaymentData.  # noqa: E501

        The unix timestamp when the payment got created  # noqa: E501

        :return: The created_at of this LightningPaymentData.  # noqa: E501
        :rtype: AllOfLightningPaymentDataCreatedAt
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this LightningPaymentData.

        The unix timestamp when the payment got created  # noqa: E501

        :param created_at: The created_at of this LightningPaymentData.  # noqa: E501
        :type: AllOfLightningPaymentDataCreatedAt
        """

        self._created_at = created_at

    @property
    def total_amount(self):
        """Gets the total_amount of this LightningPaymentData.  # noqa: E501

        The total amount (including fees) in millisatoshi  # noqa: E501

        :return: The total_amount of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this LightningPaymentData.

        The total amount (including fees) in millisatoshi  # noqa: E501

        :param total_amount: The total_amount of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._total_amount = total_amount

    @property
    def fee_amount(self):
        """Gets the fee_amount of this LightningPaymentData.  # noqa: E501

        The total fees in millisatoshi  # noqa: E501

        :return: The fee_amount of this LightningPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._fee_amount

    @fee_amount.setter
    def fee_amount(self, fee_amount):
        """Sets the fee_amount of this LightningPaymentData.

        The total fees in millisatoshi  # noqa: E501

        :param fee_amount: The fee_amount of this LightningPaymentData.  # noqa: E501
        :type: str
        """

        self._fee_amount = fee_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningPaymentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningPaymentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.server_info_api import ServerInfoApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestServerInfoApi(unittest.TestCase):
    """ServerInfoApi unit test stubs"""

    def setUp(self):
        self.api = ServerInfoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_server_info_get_server_info(self):
        """Test case for server_info_get_server_info

        Get server info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OnChainWalletOverviewData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'balance': 'str',
        'unconfirmed_balance': 'str',
        'confirmed_balance': 'str'
    }

    attribute_map = {
        'balance': 'balance',
        'unconfirmed_balance': 'unconfirmedBalance',
        'confirmed_balance': 'confirmedBalance'
    }

    def __init__(self, balance=None, unconfirmed_balance=None, confirmed_balance=None):  # noqa: E501
        """OnChainWalletOverviewData - a model defined in Swagger"""  # noqa: E501
        self._balance = None
        self._unconfirmed_balance = None
        self._confirmed_balance = None
        self.discriminator = None
        if balance is not None:
            self.balance = balance
        if unconfirmed_balance is not None:
            self.unconfirmed_balance = unconfirmed_balance
        if confirmed_balance is not None:
            self.confirmed_balance = confirmed_balance

    @property
    def balance(self):
        """Gets the balance of this OnChainWalletOverviewData.  # noqa: E501

        The total current balance of the wallet  # noqa: E501

        :return: The balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this OnChainWalletOverviewData.

        The total current balance of the wallet  # noqa: E501

        :param balance: The balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._balance = balance

    @property
    def unconfirmed_balance(self):
        """Gets the unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501

        The current unconfirmed balance of the wallet  # noqa: E501

        :return: The unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._unconfirmed_balance

    @unconfirmed_balance.setter
    def unconfirmed_balance(self, unconfirmed_balance):
        """Sets the unconfirmed_balance of this OnChainWalletOverviewData.

        The current unconfirmed balance of the wallet  # noqa: E501

        :param unconfirmed_balance: The unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._unconfirmed_balance = unconfirmed_balance

    @property
    def confirmed_balance(self):
        """Gets the confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501

        The current confirmed balance of the wallet  # noqa: E501

        :return: The confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._confirmed_balance

    @confirmed_balance.setter
    def confirmed_balance(self, confirmed_balance):
        """Sets the confirmed_balance of this OnChainWalletOverviewData.

        The current confirmed balance of the wallet  # noqa: E501

        :param confirmed_balance: The confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._confirmed_balance = confirmed_balance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OnChainWalletOverviewData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnChainWalletOverviewData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OpenLightningChannelRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_uri': 'str',
        'channel_amount': 'str',
        'fee_rate': 'float'
    }

    attribute_map = {
        'node_uri': 'nodeURI',
        'channel_amount': 'channelAmount',
        'fee_rate': 'feeRate'
    }

    def __init__(self, node_uri=None, channel_amount=None, fee_rate=None):  # noqa: E501
        """OpenLightningChannelRequest - a model defined in Swagger"""  # noqa: E501
        self._node_uri = None
        self._channel_amount = None
        self._fee_rate = None
        self.discriminator = None
        if node_uri is not None:
            self.node_uri = node_uri
        if channel_amount is not None:
            self.channel_amount = channel_amount
        if fee_rate is not None:
            self.fee_rate = fee_rate

    @property
    def node_uri(self):
        """Gets the node_uri of this OpenLightningChannelRequest.  # noqa: E501

        Node URI in the form `pubkey@endpoint[:port]`  # noqa: E501

        :return: The node_uri of this OpenLightningChannelRequest.  # noqa: E501
        :rtype: str
        """
        return self._node_uri

    @node_uri.setter
    def node_uri(self, node_uri):
        """Sets the node_uri of this OpenLightningChannelRequest.

        Node URI in the form `pubkey@endpoint[:port]`  # noqa: E501

        :param node_uri: The node_uri of this OpenLightningChannelRequest.  # noqa: E501
        :type: str
        """

        self._node_uri = node_uri

    @property
    def channel_amount(self):
        """Gets the channel_amount of this OpenLightningChannelRequest.  # noqa: E501

        The amount to fund (in satoshi)  # noqa: E501

        :return: The channel_amount of this OpenLightningChannelRequest.  # noqa: E501
        :rtype: str
        """
        return self._channel_amount

    @channel_amount.setter
    def channel_amount(self, channel_amount):
        """Sets the channel_amount of this OpenLightningChannelRequest.

        The amount to fund (in satoshi)  # noqa: E501

        :param channel_amount: The channel_amount of this OpenLightningChannelRequest.  # noqa: E501
        :type: str
        """

        self._channel_amount = channel_amount

    @property
    def fee_rate(self):
        """Gets the fee_rate of this OpenLightningChannelRequest.  # noqa: E501

        The amount to fund (in satoshi per byte)  # noqa: E501

        :return: The fee_rate of this OpenLightningChannelRequest.  # noqa: E501
        :rtype: float
        """
        return self._fee_rate

    @fee_rate.setter
    def fee_rate(self, fee_rate):
        """Sets the fee_rate of this OpenLightningChannelRequest.

        The amount to fund (in satoshi per byte)  # noqa: E501

        :param fee_rate: The fee_rate of this OpenLightningChannelRequest.  # noqa: E501
        :type: float
        """

        self._fee_rate = fee_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OpenLightningChannelRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpenLightningChannelRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
